@@ -4,7 +4,7 @@
 
 #define QT_FEATURE_webengine_v8_context_snapshot 1
 
-#define QT_FEATURE_webengine_system_pulseaudio -1
+#define QT_FEATURE_webengine_system_pulseaudio 1
 
 #define QT_FEATURE_webengine_system_gbm 1
 
@@ -18,7 +18,7 @@
 
 #define QT_FEATURE_webengine_webrtc 1
 
-#define QT_FEATURE_webengine_webrtc_pipewire -1
+#define QT_FEATURE_webengine_webrtc_pipewire 1
 
 #define QT_FEATURE_webengine_full_debug_info -1
 
